#!/usr/bin/perl

# Copyright 2008, 2009 Kevin Ryde

# This file is part of geoupload.
#
# geoupload is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# geoupload is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with geoupload.  If not, see <http://www.gnu.org/licenses/>.

use strict;
use warnings;
use ExtUtils::MakeMaker;

WriteMakefile
  (NAME         => 'geoupload',
   ABSTRACT     => 'Upload files to geocities.com',
   VERSION_FROM => 'geoupload',
   AUTHOR       => 'Kevin Ryde <user42@zip.com.au>',
   LICENSE      => 'gpl',
   SIGN         => 1,
   EXE_FILES    => [ 'geoupload' ],
   PREREQ_PM    => {
                    'LWP' => 5.819,  # libwww-perl
                    'HTML::TableExtract' => 0,
                    'Perl6::Slurp' => 0,
                    'WWW::Mechanize' => 0,

                    # builtin in recent perl anyway
                    'List::Util' => 0,
                   },

   EXTRA_META => <<'HERE',
resources:
    homepage: http://www.geocities.com/user42_kevin/geoupload/index.html
HERE
  );


sub MY::postamble {
  return <<'MAKE_FRAG';

myman:
	mv MANIFEST MANIFEST.old
	touch SIGNATURE
	(make manifest 2>&1; diff -u MANIFEST.old MANIFEST) |less

geoupload.html: geoupload Makefile
	-perl -MPod::Simple::HTML -e Pod::Simple::HTML::go \
	  geoupload >geoupload.html

LINT_FILES = $(EXE_FILES) $(TO_INST_PM)
# t/*.t
lint:
	perl -MO=Lint $(LINT_FILES)
pc:
	-podchecker $(LINT_FILES)
	perlcritic $(LINT_FILES)
unused:
	for i in $(LINT_FILES); do perl -c -Mwarnings::unused -I lib $$i; done

# find files in the dist with mod times this year, but without this year in
# the copyright line
copyright-years-check:
	year=`date +%Y`; \
	tar tvfz geoupload-$(VERSION).tar.gz \
	| egrep '$$year-|debian/copyright' \
	| sed 's:^.*geoupload-$(VERSION)/::' \
	| (result=0; \
	  while read i; do \
	    case $$i in \
	      '' | */ \
	      | debian/changelog | debian/compat \
	      | t/pod.t \
	      | COPYING | MANIFEST | SIGNATURE | META.yml) \
	      continue ;; \
	    esac; \
	    if test -e "$(srcdir)/$$i"; then f="$(srcdir)/$$i"; \
	    else f="$$i"; fi; \
	    if ! grep -q "Copyright.*$$year" $$f; then \
	      echo "$$i:1: this file"; \
	      grep Copyright $$f; \
	      result=1; \
	    fi; \
	  done; \
	  exit $$result)

debug-constants-check:
	if egrep -n 'DEBUG => [^0]' $(TO_INST_PM) $(EXE_FILES); \
	  then exit 1; else exit 0; fi

diff-prev:
	rm -rf diff.tmp
	mkdir diff.tmp
	cd diff.tmp \
	&& tar xfz ../$(NAME)-`expr $(VERSION) - 1`.tar.gz \
	&& tar xfz ../$(NAME)-$(VERSION).tar.gz
	-cd diff.tmp; diff -ur $(NAME)-`expr $(VERSION) - 1` \
	                       $(NAME)-$(VERSION) >tree.diff
	-less diff.tmp/tree.diff
	rm -rf diff.tmp

MAKE_FRAG
}
